# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blog_extension', '0008_auto_20190522_0409'),
        ('stats', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Statistics',
        ),
        migrations.DeleteModel(
            name='ViewCount',
        ),
    ]
